@@ -1,10 +1,10 @@
 //! [0]
 gzip = QProcess()
-gzip.start("gzip", QStringList() << "-c")
-if !gzip.waitForStarted():
-    return false
+gzip.start("gzip", ["-c"])
+if not gzip.waitForStarted():
+    return False
 
-gzip.write("uncompressed data");
+gzip.write("uncompressed data")
 
 compressed = QByteArray()
 while gzip.waitForReadyRead():
@@ -21,7 +21,7 @@ def bytesAvailable(self):
 //! [2]
 file = QFile("box.txt")
 if file.open(QFile.ReadOnly):
-    buf = file.readLine(1024);
+    buf = file.readLine(1024)
     if buf.size():
         # the line is available in buf
 //! [2]
@@ -29,20 +29,20 @@ if file.open(QFile.ReadOnly):
 
 //! [3]
 def canReadLine(self):
-    return buffer.contains('\n') || QIODevice.canReadLine()
+    return buffer.contains('\n') or QIODevice.canReadLine()
 //! [3]
 
 
 //! [4]
-def isExeFile(file):
-    buf = file->peek(2);
+def isExeFile(file_):
+    buf = file_.peek(2)
     if buf.size() == 2:
-        return (buf[0] == 'M' && buf[1] == 'Z')
-    return false
+        return buf[0] == 'M' and buf[1] == 'Z'
+    return False
 //! [4]
 
 
 //! [5]
-def isExeFile(file):
-    return file->peek(2) == "MZ"
+def isExeFile(file_):
+    return file_.peek(2) == "MZ"
 //! [5]
